@@ -12,6 +12,11 @@ class LayerSets(Photoshop):
 
     def __init__(self, parent):
         super().__init__(parent=parent)
+        self._flag_as_method(
+            "add",
+            "item",
+            "removeAll",
+        )
 
     def __len__(self):
         return self.length
